/// <reference types="node" />
import { Axios } from 'axios';
import { Template } from './Template';
import { RenderOptions } from 'mustache';
type TemplateCache = Record<string, {
    hits: number;
    first_hit: number;
    last_hit: number;
    template: Template;
}>;
export declare class Promptd {
    networkClient: Axios;
    cache: {
        /**
         * Time to live in milliseconds. Defaults to 5 minutes.
         *
         * @default 300000
         */
        ttl: number;
        memory: {
            /**
             * Max memory to use for caching in bytes. Defaults to 32mb.
             *
             * @default 33554432
             */
            maxBytes: number;
            /**
             * Strategy to use for caching. Defaults to lru.
             *
             * `lru` - Least Recently Used
             *
             * `lfu` - Least Frequently Used
             *
             * @default 'lru'
             */
            strategy: 'lru' | 'lfu';
        };
        /**
         * Strategy to use for network requests. Defaults to cache-while-alive.
         *
         * `stale-while-alive` - Cache the response for the time to live, then make a network request.
         *
         * `stale-while-revalidate` - Return the cached response, and revalidate in the background.
         * Next request will return the new response.
         *
         * `network-only` - Do not cache the response, and always make a network request.
         *
         * @default 'cache-while-alive'
         */
        networkStrategy: 'stale-while-alive' | 'stale-while-revalidate' | 'network-only';
    };
    templateCache: TemplateCache;
    cacheInterval: NodeJS.Timeout | null;
    constructor(options: {
        apiKey: string;
        cache?: {
            ttl?: number;
            memory?: {
                maxBytes?: number;
                strategy?: 'lru' | 'lfu';
            };
            networkStrategy?: 'stale-while-alive' | 'stale-while-revalidate' | 'network-only';
        };
    });
    private cacheTick;
    get(promptId: string): Promise<Template>;
    render<T extends Record<string, any>>(promptId: string, variables: T, options?: RenderOptions): Promise<import("./Prompt").Prompt<T>>;
}
export {};
